// Copyright (c) 2012 Cloudera, Inc.  All rights reserved.
define(["cloudera/common/I18n"], function(I18n) {
	
	return function(options) {
		var UPDATE_INTERVAL_MS = 500;
		
		var self = this;

		/**
		 * Initialize the knockout state.
		 */
		self.setupSuccessful = ko.observable(false);
		self.setupDone = ko.observable(false);
		self.showKey = ko.observable(false);
		self.progressText = ko.observable($("#progressText").text() || "");
		self.privateKey = ko.observable("");
		
		getProgress();
		
		function getProgress() {

			$.ajax({
				type: 'POST',
				url: options.cloudSetupProgressUrl,
				data: {
					configId: options.configId
				},
				success: callback,
				error: ajaxError,
				dataType: 'json'
			});
		
		}
		
		function callback(response) {
			if (response.configurator.error) {
				$("#status").attr('class', 'IconError16x16');
			} else if (response.configurator.completed) {
				$("#status").attr('class', 'IconCheckmark16x16');
			}
			
			self.progressText(response.configurator.progress);
			if (response.configurator.error) {
				self.progressText(self.progressText().replace("+", 
						response.configurator.errorText));
			}
			self.setupSuccessful(response.configurator.completed && 
				!response.configurator.error);
			self.setupDone(response.configurator.completed);
			self.privateKey(response.configurator.privateKey);
			self.showKey(self.setupSuccessful() && response.configurator.privateKey !== null);
			
			if (!self.setupDone()) {
				setTimeout(getProgress, UPDATE_INTERVAL_MS);
			}
			
			if (self.setupSuccessful()) {
				$("#quitButton").html(options.quitTerminate);
				$("#backButton").html(options.backTerminate);
			}
		}
		
		
		
		function cloudTerminate(terminateInfo) {
			window.location.href = options.cloudTerminateUrl + '?' + 
				$.param(terminateInfo);
		}
		
		self.quitClick = function(event) {
			if (self.setupSuccessful()) {
				// Load the termination progress page (terminate all started 
				// instances); after termination, navigate to exit URL.
				cloudTerminate({cloudConfigId: options.configId, postTerminate: 
					'url', postUrl: options.exitUrl});
			} else {
				quit();
			}
		};
		
		function quit() {
			window.location.href = options.exitUrl;
		}
		
		self.backClick = function(event) {
			if (self.setupSuccessful()) {
				// Load the termination progress page (terminate all started 
				// instances); after termination, go back one page from this 
				// point (from cloud-setup).
				cloudTerminate({cloudConfigId: options.configId, postTerminate: 
					'back', stepsBack: 1});
			} else {
				back();
			}
		};
		
		function back() {
			history.go(-1);
		}
		
		function ajaxError(response) {
			$.publish("showError", (response.errorMessage || I18n.t("ui.sorryAnError")) 
					+ " " + options.terminateAjaxErrorMsg);
			return false;
		}
		
	};
});
